@@ -83,8 +83,8 @@ visualisation_recipe.easycormatrix <- function(x,
 
   # Reshape to long
   data <- datawizard::reshape_longer(x,
-    cols = colnames,
-    colnames_to = "Parameter2",
+    select = colnames,
+    names_to = "Parameter2",
     values_to = "r"
   )
 
@@ -93,8 +93,8 @@ visualisation_recipe.easycormatrix <- function(x,
     data$Text <- paste0(insight::format_value(data$r, zap_small = TRUE))
   } else {
     temp <- datawizard::reshape_longer(data_text,
-      cols = colnames,
-      colnames_to = "Parameter2",
+      select = colnames,
+      names_to = "Parameter2",
       values_to = "Text"
     )
     data <- merge(data, temp, all.x = TRUE, all.y = FALSE)
